<h1 align="center">
  <br>
  <a>pyroSAR</a>
</h1>
<h3 align="center">A Python Framework for Large-Scale SAR Satellite Data Processing</h3>

<p align="center">
  <a href="https://www.travis-ci.org/johntruckenbrodt/pyroSAR"><img src="https://www.travis-ci.org/johntruckenbrodt/pyroSAR.svg?branch=master", alt="Travis Status"></a>
  <a href='https://ci.appveyor.com/project/johntruckenbrodt/pyrosar'><img src='https://ci.appveyor.com/api/projects/status/won0layps8mkss9h/branch/master?svg=true' alt='Appveyor Status' /></a>
  <a href='https://coveralls.io/github/johntruckenbrodt/pyroSAR?branch=master'>
    <img src='https://coveralls.io/repos/github/johntruckenbrodt/pyroSAR/badge.svg?branch=master' alt='Coveralls Status' />   </a>
  <a href='https://pyrosar.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/pyrosar/badge/?version=latest' alt='Documentation Status' /></a>
  <a href='https://badge.fury.io/py/pyroSAR'>
    <img src='https://badge.fury.io/py/pyroSAR.svg' alt='PIP Status' /></a>
  <a href='https://pepy.tech/project/pyroSAR'>
    <img src='http://pepy.tech/badge/pyroSAR' alt='Downloads' /></a>
</p>

The pyroSAR package aims at providing a complete solution for the scalable organization and processing of SAR satellite data:
* Reading of data from various past and present satellite missions
* Handling of acquisition metadata
* User-friendly access to processing utilities in [SNAP](https://step.esa.int/main/toolboxes/snap/) 
and [GAMMA Remote Sensing](https://www.gamma-rs.ch/) software
* Formatting of the preprocessed data for further analysis
* Export to Data Cube solutions

Head on over to [readthedocs](https://pyrosar.readthedocs.io/en/latest/?badge=latest) for installation instructions,
examples and API reference.
